# combo - content management system
# Copyright (C) 2014  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.conf.urls import url, include
from django.contrib.admin.views.decorators import staff_member_required
from django.views.decorators.cache import never_cache

import ckeditor.views as ckeditor_views

from .. import plugins
from . import views

urlpatterns = [
        url(r'^$', views.homepage, name='combo-manager-homepage'),
        url(r'^menu.json$', views.menu_json),
        url(r'^site-export$', views.site_export, name='combo-manager-site-export'),
        url(r'^site-import$', views.site_import, name='combo-manager-site-import'),
        url(r'^cells/invalid-report/$', views.invalid_cell_report, name='combo-manager-invalid-cell-report'),
        url(r'^pages/add/$', views.page_add, name='combo-manager-page-add'),
        url(r'^pages/(?P<pk>\d+)/$', views.page_view,
            name='combo-manager-page-view'),
        url(r'^pages/(?P<pk>\d+)/template$', views.page_select_template,
            name='combo-manager-page-select-template'),
        url(r'^pages/(?P<pk>\d+)/visibility$', views.page_visibility,
            name='combo-manager-page-visibility'),
        url(r'^pages/(?P<pk>\d+)/redirection$', views.page_edit_redirection,
            name='combo-manager-page-edit-redirection'),
        url(r'^pages/(?P<pk>\d+)/include-in-navigation$', views.page_edit_include_in_navigation,
            name='combo-manager-page-edit-include-in-navigation'),
        url(r'^pages/(?P<pk>\d+)/slug$', views.page_edit_slug,
            name='combo-manager-page-edit-slug'),
        url(r'^pages/(?P<pk>\d+)/title$', views.page_edit_title,
            name='combo-manager-page-edit-title'),
        url(r'^pages/(?P<pk>\d+)/description$', views.page_edit_description,
            name='combo-manager-page-edit-description'),
        url(r'^pages/(?P<pk>\d+)/picture/$', views.page_edit_picture,
            name='combo-manager-page-edit-picture'),
        url(r'^pages/(?P<pk>\d+)/remove-picture/$', views.page_remove_picture,
            name='combo-manager-page-remove-picture'),
        url(r'^pages/(?P<pk>\d+)/delete$', views.page_delete,
            name='combo-manager-page-delete'),
        url(r'^pages/(?P<pk>\d+)/export$', views.page_export,
            name='combo-manager-page-export'),
        url(r'^pages/(?P<pk>\d+)/add/$', views.page_add_child, name='combo-manager-page-add-child'),
        url(r'^pages/(?P<pk>\d+)/duplicate$', views.page_duplicate,
            name='combo-manager-page-duplicate'),
        url(r'^pages/(?P<pk>\d+)/history$', views.page_history,
            name='combo-manager-page-history'),
        url(r'^pages/(?P<page_pk>\d+)/history/(?P<pk>\d+)/$', views.snapshot_restore,
            name='combo-manager-snapshot-restore'),
        url(r'^pages/(?P<page_pk>\d+)/add-cell-to-(?P<ph_key>[\w_-]+)/(?P<cell_type>\w+)/(?P<variant>[\w-]+)/$',
            views.page_add_cell,
            name='combo-manager-page-add-cell'),
        url(r'^pages/(?P<page_pk>\d+)/cell/(?P<cell_reference>[\w_-]+)/$', views.page_edit_cell,
            name='combo-manager-page-edit-cell'),
        url(r'^pages/(?P<page_pk>\d+)/cell/(?P<cell_reference>[\w_-]+)/delete$', views.page_delete_cell,
            name='combo-manager-page-delete-cell'),
        url(r'^pages/(?P<page_pk>\d+)/cell/(?P<cell_reference>[\w_-]+)/options$',
            views.page_cell_options,
            name='combo-manager-page-options-cell'),
        url(r'^pages/(?P<page_pk>\d+)/cell/(?P<cell_reference>[\w_-]+)/visibility$',
            views.page_cell_visibility,
            name='combo-manager-page-visibility-cell'),
        url(r'^pages/(?P<page_pk>\d+)/cell/(?P<cell_reference>[\w_-]+)/label$',
            views.page_get_additional_label, name='combo-manager-page-get-additional-label'),
        url(r'^pages/(?P<page_pk>\d+)/cell/(?P<cell_reference>[\w_-]+)/add-link/(?P<link_code>[\w-]+)$',
            views.page_list_cell_add_link,
            name='combo-manager-page-list-cell-add-link'),
        url(r'^pages/(?P<page_pk>\d+)/cell/(?P<cell_reference>[\w_-]+)/link/(?P<link_cell_reference>[\w_-]+)/$',
            views.page_list_cell_edit_link,
            name='combo-manager-page-list-cell-edit-link'),
        url(r'^pages/(?P<page_pk>\d+)/cell/(?P<cell_reference>[\w_-]+)/link/(?P<link_cell_reference>[\w_-]+)/delete$',
            views.page_list_cell_delete_link,
            name='combo-manager-page-list-cell-delete-link'),
        url(r'^pages/(?P<page_pk>\d+)/cell/(?P<cell_reference>[\w_-]+)/order$',
            views.link_list_order,
            name='combo-manager-link-list-order'),
        url(r'^pages/(?P<page_pk>\d+)/order$', views.cell_order,
            name='combo-manager-cell-order'),
        url(r'^pages/order$', views.page_order,
            name='combo-manager-page-order'),
        url(r'^ckeditor/upload/', staff_member_required(ckeditor_views.upload),
            name='ckeditor_upload'),
        url(r'^ckeditor/browse/', never_cache(staff_member_required(ckeditor_views.browse)),
            name='ckeditor_browse'),
]

urlpatterns = plugins.register_plugins_manager_urls(urlpatterns)
